; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[command]
name = "kamikazi"
command = ~D, DB, B, F, a
time = 40

[command]
name = "big kame"
command = ~D, DB, B, b
time = 30

[command]
name = "small kame"
command = ~D, DF, F, b
time = 30

[command]
name = "goten explode"
command = ~D, DB, B, x
time = 30

[command]
name = "triform"
command = ~D, DB, B, F, x
time = 30

[command]
name = "zap"
command = ~D, DB, B, F, y
time = 30

[command]
name = "rolling thunder"
command = ~D, DF, F, D, DF, F, b
time = 30

[command]
name = "homing renzoku"
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = "big_renzoku"
command = ~D, DB, B, D, DB, B, a
time = 30

[Command]
name = "renzoku shine"
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = "triple"
command =  a
time = 30

[Command]
name = "forty five"
command = ~D, DB, B, a
time = 40

[Command]
name = "five forty"
command = ~D, DF, F, a
time = 40

;-| Special Motions |------------------------------------------------------
;-----------------
[command]
name = "b_kick"
command = ~D, F, x

[Command]
name = "wild boar"
command = D, DF, F, y

; big fireball
[Command]
name = "blast"
command = F, B, F, a
time = 30

[Command]
name = "uppercut"
command = ~D, DF, F, D, DF, F, y
time = 30

[command]
name = "headbutt"
command = ~D, DF, F, b

[command]
name = "slide"
command = x

[command]
name = "fireup"
command = /U, a

[command]
name = "firedown"
command = /D, a

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ultra headbutt"
command = y+x
time = 1

[Command]
name = "ultra headbutt2"
command = a+b
time = 1

[Command]
name = "zanzoken"
command = a+x

[Command]
name = "zanzoken2"
command = b+y

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,b
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_yb"
command = /F, y+b
time = 1

[Command]
name = "back_yb"
command = /B, y+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "charge"
command = /c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "fly"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_yb"
command = /y+b
time = 30

[Command]
name = "hold_xa"
command = /x+a
time = 30

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 30

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 30

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
ultra headbutt
[state -1]
type = changestate
value = 750
triggerall = command = "ultra headbutt2"
trigger1 = statetype = S
trigger1 = ctrl = 1

[state -1]
type = changestate
value = 750
triggerall = command = "ultra headbutt"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
kamikaze
[state -1]
type = changestate
value = 3070
triggerall = command = "kamikazi"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1

kamikaze
[state -1]
type = changestate
value = 3080
triggerall = command = "kamikazi"
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900


;---------------------------------------------------------------------------
homing renzoku
[state -1]
type = changestate
value = 3060
triggerall = command = "homing renzoku"
triggerall = power >= 1800
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
zap
[state -1]
type = changestate
value = 3000
triggerall = command = "zap"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 2000
trigger2 = stateno = 3001
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
triform
[state -1]
type = changestate
value = 3005
triggerall = command = "triform"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1600
trigger2 = stateno = 3006
trigger2 = movecontact = 1
trigger3 = stateno = 3007
trigger3 = numproj = 0

;---------------------------------------------------------------------------
big renzoku shine
[State -1]
type = ChangeState
value = 3010
trigger1 = command = "big_renzoku"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 2000

;---------------------------------------------------------------------------
big kamehameha
[State -1]
type = ChangeState
value = 3090
trigger1 = command = "big kame"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 2000

;---------------------------------------------------------------------------
renzoku shine
[State -1]
type = ChangeState
value = 1506
trigger1 = command = "renzoku shine"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1000

;---------------------------------------------------------------------------
rolling thunder
[state -1]
type = changestate
value = 3020
triggerall = command = "rolling thunder"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1000
trigger2 = stateno = 3021
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
spinning uppercut
[state -1]
type = changestate
value = 3030
triggerall = command = "uppercut"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1000
trigger2 = stateno = 3031
trigger2 = movecontact = 0
trigger2 = stateno = 3032
trigger2 = movecontact = 0
trigger2 = stateno = 3033
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
wild boar
[State -1]
type = changestate
value = 3299
triggerall = command = "wild boar"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 500
trigger2 = stateno = 3300
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
big kick
[state -1]
type = changestate
value = 1020
triggerall = command = "b_kick"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
zanzoken
[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

zanzoken
[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger1 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071

;---------------------------------------------------------------------------
zanzoken2
[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

zanzoken2
[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger1 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071


;---------------------------------------------------------------------------

goten explode
[state -1]
type = changestate
value = 3050
triggerall = command = "goten explode"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1500
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_b";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;---------------------------------------------------------------------------
; charge
[State -1]
type = ChangeState
value = 700
triggerall = power < 3000
trigger1 = command = "charge"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; air charge
[State -1]
type = ChangeState
value = 702
triggerall = power < 3000
triggerall = command = "charge"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; fly 
[State -1]
type = ChangeState
value = 1800
triggerall = command = "fly"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fly when jumping
[State -1]
type = ChangeState
value = 1900
triggerall = command = "fly"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; ultra headbutt 
[State -1]
type = ChangeState
value = 1090
triggerall = command = "ultra headbutt"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fireball
[State -1]
type = ChangeState
value = 1000
trigger1 = command = "a"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fireball up
[State -1]
type = ChangeState
value = 1001
triggerall = command = "fireup"
trigger1 = numproj = 0
trigger1 = ctrl = 1
trigger1 = statetype = A
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; fireball down
[State -1]
type = ChangeState
value = 1002
triggerall = command = "firedown"
trigger1 = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
triple fireball
[State -1]
type = ChangeState
value = 1004
trigger1 = command = "triple"
trigger1 = numproj = 0
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger1 = power >= 0

;---------------------------------------------------------------------------
; for fiv fireball
[State -1]
type = ChangeState
value = 1007
triggerall = command = "five forty"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

; for fiv fireball
[State -1]
type = ChangeState
value = 1008
triggerall = command = "forty five"
trigger1 = p2dist Y < 0
trigger1 = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
slide
[State -1]
type = ChangeState
value = 1040
triggerall = command = "slide"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 1041

;---------------------------------------------------------------------------
; big fireball
[State -1]
type = ChangeState
value = 1003
triggerall = command = "blast"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; punch
[State -1]
type = ChangeState
value = 200
triggerall = command = "y";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; headbutt
[State -1]
type = ChangeState
value = 1009
triggerall = command = "headbutt"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; slash
[State -1]
type = ChangeState
value = 202
triggerall = command = "x";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;----------------------------------------------------------------------------
 
; kick
[State -1]
type = ChangeState
value = 203
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; crouch punch
[State -1]
type = ChangeState
value = 400
triggerall = command = "y"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; crouch kick
[State -1]
type = ChangeState
value = 401
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
; jump kick
[State -1]
type = ChangeState
value = 603
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; jump punch
[State -1]
type = ChangeState
value = 601
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; slash
[State -1]
type = ChangeState
value = 604
triggerall = command = "x";Place name of command here
trigger1 = statetype = A
trigger1 = ctrl = 1
